@@ -41,9 +41,9 @@ def unix():
 
 def stopwatch_start():
   global stopwatchStartTime
-  stopwatchStartTime = time.time()
+  stopwatchStartTime = round(time.time(), 2)
   return "Started!"
 def stopwatch_stop():
-  stopwatchLength = time.time() - stopwatchStartTime
+  stopwatchLength = round(time.time(), 2) - stopwatchStartTime
   return stopwatchLength
 
